

### Intro
> setuptools_scm, as the name says, retrieves the package version from scm metadata instead of from an explicit declaration. Again, coming back to human errors, if you work with a version control system such as Git and publish releases on GitHub, you’re working with scm metadata already anyway.

### Reference(s):
- https://github.com/pypa/setuptools_scm
- https://www.moritzkoerber.com/posts/versioning-with-setuptools_scm/
